document.addEventListener('DOMContentLoaded', () => {
  const form = document.getElementById('cognitiveTest');
  const results = document.getElementById('results');
  const scoreElement = document.getElementById('score');
  const severityLevel = document.getElementById('severity-level');
  const recommendationsDiv = document.getElementById('recommendations');

  form.addEventListener('submit', (e) => {
    e.preventDefault();
    
    const formData = new FormData(form);
    let totalScore = 0;
    
    for (let value of formData.values()) {
      totalScore += parseInt(value);
    }

    scoreElement.textContent = totalScore;
    
    // Determine severity level
    let severity = '';
    let recommendations = '';
    
    if (totalScore <= 5) {
      severity = 'Minimal cognitive concerns';
      recommendations = `
        <h3>Recommendations:</h3>
        <ul>
          <li>Continue regular mental stimulation through play and training</li>
          <li>Maintain regular exercise routine</li>
          <li>Regular veterinary check-ups</li>
        </ul>
      `;
    } else if (totalScore <= 10) {
      severity = 'Mild cognitive concerns';
      recommendations = `
        <h3>Recommendations:</h3>
        <ul>
          <li>Increase mental enrichment activities</li>
          <li>Consider brain-training games</li>
          <li>Maintain consistent daily routines</li>
          <li>Discuss with your vet about preventive measures</li>
        </ul>
      `;
    } else if (totalScore <= 15) {
      severity = 'Moderate cognitive concerns';
      recommendations = `
        <h3>Recommendations:</h3>
        <ul>
          <li>Schedule a veterinary appointment soon</li>
          <li>Consider dietary supplements (after vet consultation)</li>
          <li>Implement environmental enrichment</li>
          <li>Establish strict routine for feeding and walks</li>
          <li>Monitor changes more closely</li>
        </ul>
      `;
    } else {
      severity = 'Significant cognitive concerns';
      recommendations = `
        <h3>Recommendations:</h3>
        <ul>
          <li>Immediate veterinary consultation recommended</li>
          <li>Discuss medication options with your vet</li>
          <li>Adapt home environment for safety</li>
          <li>Consider night lights and anxiety management</li>
          <li>Monitor eating, drinking, and bathroom habits closely</li>
        </ul>
      `;
    }
    
    severityLevel.textContent = severity;
    recommendationsDiv.innerHTML = recommendations;
    
    // Show results
    results.classList.remove('hidden');
    results.scrollIntoView({ behavior: 'smooth' });
  });

  // Add animation to score display
  const animateScore = (finalScore) => {
    let currentScore = 0;
    const duration = 1000; // 1 second
    const increment = finalScore / (duration / 16); // 60 FPS
    
    const animation = setInterval(() => {
      currentScore += increment;
      if (currentScore >= finalScore) {
        currentScore = finalScore;
        clearInterval(animation);
      }
      scoreElement.textContent = Math.round(currentScore);
    }, 16);
  };
});
